@@ -348,14 +348,13 @@ impl Client {
 
 #[cfg(test)]
 mod tests {
-    use super::{Chunk, ChunkAddress, Client, DataMap, DataMapLevel, Error};
+    use super::{ChunkAddress, Client, DataMap, DataMapLevel};
     use crate::client::client_api::blob_storage::BlobStorage;
     use crate::client::utils::{
         generate_random_vector,
         test_utils::{create_test_client, run_w_backoff_delayed},
     };
     use crate::retry_err_loop;
-    use crate::types::{PrivateChunk, PublicChunk};
     use anyhow::{anyhow, bail, Result};
     use bincode::deserialize;
     use futures::future::join_all;
@@ -689,25 +688,6 @@ mod tests {
 
         let client = create_test_client(Some(BLOB_TEST_QUERY_TIMEOUT)).await?;
 
-        // generate address without storing to the network (public and unencrypted)
-        let chunk = if public {
-            Chunk::Public(PublicChunk::new(raw_data.clone()))
-        } else {
-            Chunk::Private(PrivateChunk::new(raw_data.clone(), client.public_key()))
-        };
-
-        let address_before = chunk.address();
-
-        // attempt to retrieve it with generated address (it should error, i.e. timeout)
-        let res = client.read_blob(*address_before, None, None).await;
-        match res {
-            Err(Error::NoResponse) => (),
-            Ok(_) => bail!("Blob unexpectedly retrieved using address generated by gen_data_map"),
-            Err(_) => bail!(
-                "Unexpected error when Blob retrieved using address generated by gen_data_map"
-            ),
-        };
-
         let address = if public {
             client.store_public_blob(&raw_data).await?
         } else {
