@@ -8,8 +8,8 @@
 
 use super::wire_msg_header::WireMsgHeader;
 use crate::messaging::{
-    data::DataMsg, node::NodeMsg, section_info::SectionInfoMsg, DstLocation, Error, MessageId,
-    MessageType, MsgKind, NodeMsgAuthority, Result,
+    data::DataMsg, node::NodeMsg, section_info::SectionInfoMsg, Authority, DstLocation, Error,
+    MessageId, MessageType, MsgKind, NodeMsgAuthority, Result,
 };
 use bls::PublicKey as BlsPublicKey;
 use bytes::Bytes;
@@ -132,7 +132,7 @@ impl WireMsg {
 
                 Ok(MessageType::Client {
                     msg_id: self.header.msg_envelope.msg_id,
-                    data_auth: data_signed.verify(&self.payload)?,
+                    data_auth: Authority::verify(data_signed, &self.payload)?,
                     dst_location: self.header.msg_envelope.dst_location,
                     msg,
                 })
@@ -144,7 +144,10 @@ impl WireMsg {
 
                 Ok(MessageType::Node {
                     msg_id: self.header.msg_envelope.msg_id,
-                    msg_authority: NodeMsgAuthority::Node(node_signed),
+                    msg_authority: NodeMsgAuthority::Node(Authority::verify(
+                        node_signed,
+                        &self.payload,
+                    )?),
                     dst_location: self.header.msg_envelope.dst_location,
                     msg,
                 })
@@ -159,7 +162,10 @@ impl WireMsg {
 
                 Ok(MessageType::Node {
                     msg_id: self.header.msg_envelope.msg_id,
-                    msg_authority: NodeMsgAuthority::BlsShare(bls_share_signed),
+                    msg_authority: NodeMsgAuthority::BlsShare(Authority::verify(
+                        bls_share_signed,
+                        &self.payload,
+                    )?),
                     dst_location: self.header.msg_envelope.dst_location,
                     msg,
                 })
@@ -174,7 +180,10 @@ impl WireMsg {
 
                 Ok(MessageType::Node {
                     msg_id: self.header.msg_envelope.msg_id,
-                    msg_authority: NodeMsgAuthority::Section(section_signed),
+                    msg_authority: NodeMsgAuthority::Section(Authority::verify(
+                        section_signed,
+                        &self.payload,
+                    )?),
                     dst_location: self.header.msg_envelope.dst_location,
                     msg,
                 })
@@ -241,14 +250,13 @@ mod tests {
     use crate::{
         messaging::{
             data::{ChunkRead, DataMsg, DataQuery, ProcessMsg},
-            node::{NodeCmd, NodeMsg, NodeSystemCmd},
-            DataSigned, MessageId, NodeSigned,
+            node::{NodeCmd, NodeMsg},
+            Authority, DataSigned, MessageId, NodeSigned,
         },
         types::{ChunkAddress, Keypair},
     };
     use anyhow::Result;
     use bls::SecretKey;
-    use ed25519_dalek::Signer;
     use rand::rngs::OsRng;
     use xor_name::XorName;
 
@@ -352,19 +360,15 @@ mod tests {
         let msg_id = MessageId::new();
         let pk = crate::types::PublicKey::Bls(dst_section_pk);
 
-        let node_msg = NodeMsg::NodeCmd(NodeCmd::System(NodeSystemCmd::StorageFull {
+        let node_msg = NodeMsg::NodeCmd(NodeCmd::StorageFull {
             node_id: pk,
             section: pk.into(),
-        }));
+        });
 
         let payload = WireMsg::serialize_msg_payload(&node_msg)?;
-        let node_signed = NodeSigned {
-            section_pk: src_section_pk,
-            public_key: src_node_keypair.public,
-            signature: src_node_keypair.sign(&payload),
-        };
+        let node_auth = NodeSigned::authorize(src_section_pk, &src_node_keypair, &payload);
 
-        let msg_kind = MsgKind::NodeSignedMsg(node_signed.clone());
+        let msg_kind = MsgKind::NodeSignedMsg(node_auth.clone().into_inner());
 
         let wire_msg = WireMsg::new_msg(msg_id, payload, msg_kind, dst_location)?;
         let serialized = wire_msg.serialize()?;
@@ -382,7 +386,7 @@ mod tests {
             deserialized.into_message()?,
             MessageType::Node {
                 msg_id: wire_msg.msg_id(),
-                msg_authority: NodeMsgAuthority::Node(node_signed),
+                msg_authority: NodeMsgAuthority::Node(node_auth),
                 dst_location,
                 msg: node_msg,
             }
@@ -414,7 +418,7 @@ mod tests {
             public_key: src_client_keypair.public_key(),
             signature: src_client_keypair.sign(&payload),
         };
-        let data_auth = data_signed.clone().verify(&payload).unwrap();
+        let data_auth = Authority::verify(data_signed.clone(), &payload).unwrap();
 
         let msg_kind = MsgKind::DataMsg(data_signed);
 
